from setuptools import setup

setup(
    name='tigran_test',
    version='0.1', 
    description='My package', 
    url='https://github.com/ruperson/tigran_test', 
    install_requires=['matplotlib'],  
    packages=['tigran_test'],  
)